Stack Configurations
====================


 .. autoclass:: squidasm.run.stack.config.StackConfig
    :members:
    :undoc-members:
    :member-order: bysource

 .. autoclass:: squidasm.run.stack.config.GenericQDeviceConfig
    :members:
    :undoc-members:
    :member-order: bysource

 .. autoclass:: squidasm.run.stack.config.NVQDeviceConfig
    :members:
    :undoc-members:
    :member-order: bysource